# Добавить несколько файлов к кандидату - описание запроса

`POST/open-api/objects/candidates/{candidateId}/file`

Этот endpoint позволяет загрузить один файл к существующему кандидату. Для данного запроса необходимо передавать данные, используя многопартные запросы (multipart/form-data).Добавленный файл отобразится на вкладке "Вложения" в карточке кандидата.

# Параметры и тело запроса

## PATH PARAMETRS

| **Id** | **Тип данных** | **Название и Описание** | **Допустимые форматы/значения** |
| --- | --- | --- | --- |
| `candidateId` | string | Id кандидата | **Обязательное поле** |

## QUERY PARAMETRS

| Id  | Тип данных | Название и Описание | Допустимые форматы/значения |
| --- | --- | --- | --- |
| `fileType` | string | Тип файла. Допустимые значения: `resume` - Файл резюме, `avatar` - аватар (фото), `testResultDataFile` - результаты тестов, `documents` - прочие документы, `education` - документы об образовании | **Обязательное поле** |

&nbsp;

## REQUEST BODY SCHEMA

| **Id** | **Тип данных** | **Название и Описание** | **Допустимые форматы/значения** |
| --- | --- | --- | --- |
| `file` | string &lt;binary&gt; | Файл. Поддерживаемые расширения - `.pdf`, `.doc`, `.docx`, `.rtf`, `.txt`,`.xls`, `.xlsx`, `.png`, `.jpg`, `.mpeg`, `.mp4`, `.avi`, `.mov`, `.mkv`, `.webm`, `.mp3`, `.midi`, `.wav`, `.pptx`, `.pptm`, `.potx`, `.potm`, `.msg`, `.eml`, `.ics`, `.vcs`. Размер файла - не более 10 Мб. | **Обязательное поле** |
|     |     |     |     |

# Responses

## RESPONSE SCHEMA

| **Id** | **Тип данных** | **Название и Описание** | **Допустимые форматы/значения** |
| --- | --- | --- | --- |
| `CandidateId` | string | Id кандидата | **Обязательное поле** |
| `Result` | object (CandidateFileUploadResult) | Результат | **Обязательное поле** |

Описание объекта `CandidateFileUploadResult`

| **Id** | **Тип данных** | **Название и Описание** | **Допустимые форматы/значения** |
| --- | --- | --- | --- |
| `IsOk` | boolean | <span style="color: #333333;">Успешно ли загружен файл</span> |     |
| `FileId` | string | Id файла |     |
| `FileName` | string | Имя файла |     |
| `ErrorMessage` | string | Сообщение об ошибке |     |

# Примеры использования

## Пример cURL запроса на добавление файла резюме к кандидату

```cURL
curl --location --globoff 'https://api.dev.skillaz.ru/open-api/objects/candidates/{candidateId}/file?fileType=resume' \
--header 'Authorization: Bearer {token}' \
--form 'file=@"/C:/Users/login/Рабочий стол/Резюме.pdf"'
```

## Ответ на успешный запрос

Возвращается код `200 Успешно` с телом вида

```JSON
{
    "CandidateId": "65d7105ce9aabc65e414bfc8",
    "Result": {
        "IsOk": true,
        "FileId": "65ef22d38effba47b6cad790",
        "FileName": "33.jpg",
        "ErrorMessage": null
    }
}
```

## Примеры частых ошибок

### Пример ошибки  - слишком большой файл

В ответе на запрос получите ошибку `400` с расшифровкой вида:

```Json
{
    "errors": {
        "": [
            "Failed to read the request form. Request body too large. The max request body size is 10485760 bytes."
        ]
    },
    "type": "https://api.skillaz.ru/help/swagger",
    "title": "Validation error",
    "status": 400,
    "detail": "Please refer to the errors property for additional details.",
    "instance": "/open-api/objects/candidates/65d7105ce9aabc65e414bfc8/file",
    "requestId": "0HN1S9QQIIL0F:00000002"
}
```

### Пример ошибки - не поддерживаемое расширение файла

В ответе на запрос получите ошибку `400` с расшифровкой вида:

```json
{
    "Type": "https://api.skillaz.ru/help/swagger",
    "Title": "Failed to upload file",
    "Status": 400,
    "Detail": "allowedToAttachFileTypes. Поддерживаемые расширения - Pdf, Doc, DocX, Rtf, Txt, Xls, Xlsx, Png, Jpg, Mpeg, Mp4, Avi, Mov, Mkv, Webm, Mp3, Midi, Wav, Pptx, Pptm, Potx, Potm, Msg, Eml, Ics, Vcs",
    "Instance": null,
    "Extensions": {
        "requestId": "0HN1S9QQIIL4D:00000001",
        "externalRequestId": "685761c4680031c3825d94d22d5857e9"
    }
}
```

&nbsp;
